==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/ServerConnection.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SERVERCONNECTION_H_
#define SERVERCONNECTION_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "AsyncConnection.h"
#include "HttpVersion.h"

class ServerConnection : public AsyncConnection
{
public:
	ServerConnection();
	
	virtual ~ServerConnection();
	
	bool isExpectedToPersist() const { return m_willPersist; }
	
	void toBeClosed() { m_willPersist = false; }
	
	int getNumResponses() const { return m_numResponses; }
	
	HttpVersion const& getMinResponseVersion() const { return m_minResponseVersion; }
	
	HttpVersion const& getMaxResponseVersion() const { return m_maxResponseVersion; }
	
	void registerResponse(HttpVersion const& version);
private:
	virtual void onNewConnection();
	
	bool m_willPersist;
	int m_numResponses;
	HttpVersion m_minResponseVersion;
	HttpVersion m_maxResponseVersion;
};

#endif

==> bfilter_1.0.2.orig.tar.gz: bfilter-1.0.2/main/ServerConnection.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SERVERCONNECTION_H_
#define SERVERCONNECTION_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "SymbolicInetAddr.h"
#include "HttpVersion.h"
#include <ace/config-lite.h>
#include <ace/SOCK_Stream.h>

class ServerConnection
{
public:
	ServerConnection(SymbolicInetAddr const& addr, ACE_SOCK_Stream const& peer);
	
	~ServerConnection();
	
	ACE_SOCK_Stream const& peer() const { return m_peer; }
	
	SymbolicInetAddr const& getAddress() const { return m_symbolicAddr; }
	
	bool isSameAddress(SymbolicInetAddr const& addr) const { return addr == m_symbolicAddr; }
	
	bool isExpectedToPersist() const { return m_willPersist; }
	
	void toBeClosed() { m_willPersist = false; }
	
	int getNumResponses() const { return m_numResponses; }
	
	HttpVersion const& getMinResponseVersion() const { return m_minResponseVersion; }
	
	HttpVersion const& getMaxResponseVersion() const { return m_maxResponseVersion; }
	
	void registerResponse(HttpVersion const& version);
	
	void setTcpNoDelay(bool value = true);
private:
	SymbolicInetAddr m_symbolicAddr;
	ACE_SOCK_Stream m_peer;
	bool m_willPersist;
	int m_numResponses;
	HttpVersion m_minResponseVersion;
	HttpVersion m_maxResponseVersion;
};

#endif
